@@ -784,30 +784,12 @@ namespace Tomboy
 		/// </summary>
 		public string GetCompleteNoteXml ()
 		{
-			if (!File.Exists (filepath))
-				return null;
-
-			// Make sure file contents are up to date
-			save_needed = true; // HACK: Catches newly created notes
-			Save ();
-
-			StreamReader reader = null;
-			try {
-				reader = new StreamReader (filepath);
-				return reader.ReadToEnd ();
-			} catch (Exception e) {
-				Logger.Error ("Error received while attempting to read " +
-				              filepath + ": " + e.Message);
-				return null;
-			} finally {
-				if (reader != null)
-					reader.Close ();
-			}
+			return NoteArchiver.WriteString (data.GetDataSynchronized ());
 		}
 
 		// Reload note data from a complete note XML string
 		// Should referesh note window, too
-		public void LoadForeignNoteXml (string foreignNoteXml)
+		public void LoadForeignNoteXml (string foreignNoteXml, ChangeType changeType)
 		{
 			if (foreignNoteXml == null)
 				throw new ArgumentNullException ("foreignNoteXml");
@@ -870,7 +852,8 @@ namespace Tomboy
 
 			xml.Close ();
 
-			// TODO: Any reason to queue a save here?  Maybe not for sync but for others?
+			// Allow method caller to specify ChangeType (mostly needed by sync)
+			QueueSave (changeType);
 		}
 
 		// TODO: CODE DUPLICATION SUCKS
@@ -1243,6 +1226,16 @@ namespace Tomboy
 			return note;
 		}
 
+		public static string WriteString(NoteData note)
+		{
+			StringWriter str = new StringWriter ();
+			XmlWriter xml = XmlWriter.Create (str, XmlEncoder.DocumentSettings);
+			Instance.Write (xml, note);
+			xml.Close ();
+			str.Flush();
+			return str.ToString ();
+		}
+
 		public static void Write (string write_file, NoteData note)
 		{
 			Instance.WriteFile (write_file, note);
@@ -1252,7 +1245,7 @@ namespace Tomboy
 		{
 			string tmp_file = write_file + ".tmp";
 
-			XmlTextWriter xml = new XmlTextWriter (tmp_file, System.Text.Encoding.UTF8);
+			XmlWriter xml = XmlWriter.Create (tmp_file, XmlEncoder.DocumentSettings);
 			Write (xml, note);
 			xml.Close ();
 
@@ -1282,15 +1275,13 @@ namespace Tomboy
 
 		public void WriteFile (TextWriter writer, NoteData note)
 		{
-			XmlTextWriter xml = new XmlTextWriter (writer);
+			XmlWriter xml = XmlWriter.Create (writer, XmlEncoder.DocumentSettings);
 			Write (xml, note);
 			xml.Close ();
 		}
 
-		void Write (XmlTextWriter xml, NoteData note)
+		void Write (XmlWriter xml, NoteData note)
 		{
-			xml.Formatting = Formatting.Indented;
-
 			xml.WriteStartDocument ();
 			xml.WriteStartElement (null, "note", "http://beatniksoftware.com/tomboy");
 			xml.WriteAttributeString(null,
