@@ -191,7 +191,9 @@ namespace Tomboy
                         // Use another VBox to place the MenuBar
                         // right at thetop of the window.
                         content_vbox = new Gtk.VBox (false, 0);
+#if !MAC
                         content_vbox.PackStart (menu_bar, false, false, 0);
+#endif
                         content_vbox.PackStart (vbox, true, true, 0);
                         content_vbox.Show ();
 
@@ -962,9 +964,10 @@ namespace Tomboy
                         Hide ();
                         Destroy ();
                         instance = null;
-
+#if !MAC
                         if (Tomboy.TrayIconShowing == false)
                                 Tomboy.ActionManager ["QuitTomboyAction"].Activate ();
+#endif
                 }
 
                 void OnDelete (object sender, Gtk.DeleteEventArgs args)
@@ -1235,10 +1238,10 @@ namespace Tomboy
 			Notebooks.NotebookManager.PromptDeleteNotebook (this, notebook);
 		}
 
-		// Open the notebook's note template when activated
+		// Create a new note in the notebook when activated
 		private void OnNotebookRowActivated (object sender, Gtk.RowActivatedArgs args)
 		{
-			OnOpenNotebookTemplateNote (sender, EventArgs.Empty);
+			OnNewNotebookNote (sender, EventArgs.Empty);
 		}
 		
 		private void OnNewNotebookNote (object sender, EventArgs args)
