@@ -2,18 +2,20 @@
 using System;
 using System.Collections;
 using System.Collections.Generic;
-
+#if ENABLE_DBUS
 using NDesk.DBus;
 using org.freedesktop.DBus;
+#endif
 
 namespace Tomboy
 {
 	public delegate void RemoteDeletedHandler (string uri, string title);
 	public delegate void RemoteAddedHandler (string uri);
 	public delegate void RemoteSavedHandler (string uri);
-
+#if ENABLE_DBUS
 	[Interface ("org.gnome.Tomboy.RemoteControl")]
-	public class RemoteControl : MarshalByRefObject
+#endif
+	public class RemoteControl : MarshalByRefObject, IRemoteControl
 	{
 		private NoteManager note_manager;
 
@@ -246,7 +248,7 @@ namespace Tomboy
 			note = note_manager.FindByUri (uri);
 			if (note == null)
 				return false;
-			note.LoadForeignNoteXml (xml_contents);
+			note.LoadForeignNoteXml (xml_contents, ChangeType.ContentChanged);
 			return true;
 		}
 
